from pathlib import Path

from sdgx.models.statistics.single_table.copula import GaussianCopulaSynthesizer
from sdgx.utils import get_demo_single_table


def test_gaussian_copula(demo_single_table_path):
    demo_data, discrete_cols = get_demo_single_table(Path(demo_single_table_path).parent)
    model = GaussianCopulaSynthesizer(discrete_cols)
    model.fit(demo_data)

    sampled_data = model.sample(10)
    assert len(sampled_data) == 10



from functools import wraps

import click

from sdgx.cli.message import ExceptionMessage, NormalMessage
from sdgx.log import LOG_TO_FILE, add_log_file_handler, logger


def cli_wrapper(func):
    @click.option("--json_output", type=bool, default=False, help="Exit with json output.")
    @click.option("--log_to_file", type=bool, default=False, help="Log to file.")
    @wraps(func)
    def wrapper(json_output, log_to_file, *args, **kwargs):
        if log_to_file and not LOG_TO_FILE:
            add_log_file_handler()
        try:
            func(*args, **kwargs)
        except Exception as e:
            logger.exception(e)
            if json_output:
                ExceptionMessage.from_exception(e).send()
            exit(getattr(e, "EXIT_CODE", -1))
        else:
            if json_output:
                NormalMessage().send()
            exit(0)

    return wrapper
